% Auto-generated chapter 15 for malik
% Hadiths in this chapter: 50

\hadithdefcmd{malik}{470}{\hadithno{470}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{}}
\hadithdefcmd{malik}{471}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَيُّوبَ بْنِ أَبِي تَمِيمَةَ السَّخْتِيَانِيِّ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، كَانَ فِي قَوْمٍ وَهُمْ يَقْرَءُونَ الْقُرْآنَ فَذَهَبَ لِحَاجَتِهِ ثُمَّ رَجَعَ وَهُوَ يَقْرَأُ الْقُرْآنَ فَقَالَ لَهُ رَجُلٌ يَا أَمِيرَ الْمُؤْمِنِينَ أَتَقْرَأُ الْقُرْآنَ وَلَسْتَ عَلَى وُضُوءٍ فَقَالَ لَهُ عُمَرُ مَنْ أَفْتَاكَ بِهَذَا أَمُسَيْلِمَةُ\hadithno{471}\hadithgrade{Salim al-Hilali: Mauquf Sahih Lighairihi}\hadithtrans{}}
\hadithdefcmd{malik}{472}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنِ الأَعْرَجِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدٍ الْقَارِيِّ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ مَنْ فَاتَهُ حِزْبُهُ مِنَ اللَّيْلِ فَقَرَأَهُ حِينَ تَزُولُ الشَّمْسُ إِلَى صَلاَةِ الظُّهْرِ فَإِنَّهُ لَمْ يَفُتْهُ أَوْ كَأَنَّهُ أَدْرَكَهُ ‏.‏\hadithno{472}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Dawud ibn al-Husayn from al- Araj from Abd ar-Rahman ibn Abd al-Qari that Umar ibn al Khattab said, "Whoever misses reading his hizb at night and reads it from when the sun has passed the meridian until the dhuhr prayer has not missed it, or it is as if he has caught it}}
\hadithdefcmd{malik}{473}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ كُنْتُ أَنَا وَمُحَمَّدُ بْنُ يَحْيَى بْنِ حَبَّانَ، جَالِسَيْنِ فَدَعَا مُحَمَّدٌ رَجُلاً فَقَالَ أَخْبِرْنِي بِالَّذِي، سَمِعْتَ مِنْ، أَبِيكَ ‏.‏ فَقَالَ الرَّجُلُ أَخْبَرَنِي أَبِي أَنَّهُ، أَتَى زَيْدَ بْنَ ثَابِتٍ فَقَالَ لَهُ كَيْفَ تَرَى فِي قِرَاءَةِ الْقُرْآنِ فِي سَبْعٍ فَقَالَ زَيْدٌ حَسَنٌ وَلأَنْ أَقْرَأَهُ فِي نِصْفٍ أَوْ عَشْرٍ أَحَبُّ إِلَىَّ وَسَلْنِي لِمَ ذَاكَ قَالَ فَإِنِّي أَسْأَلُكَ ‏.‏ قَالَ زَيْدٌ لِكَىْ أَتَدَبَّرَهُ وَأَقِفَ عَلَيْهِ ‏.‏\hadithno{473}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said, "Once Muhammad ibn Yahya ibn Habban and I were sitting down, and Muhammad called a man over to him and said to him, 'Tell me what you have heard from your father.' The man replied that his father had told him that he went to Zayd ibn Thabit and asked him, 'What do you think of reciting the whole Qur'an in seven days?' Zayd said, 'That's good, but I prefer to recite it in two weeks, or ten days. Ask me why that is.' He said, 'I ask you then.' Zayd said, 'So that I can reflect on it and pause in it}}
\hadithdefcmd{malik}{474}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدٍ الْقَارِيِّ، أَنَّهُ قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ سَمِعْتُ هِشَامَ بْنَ حَكِيمِ بْنِ حِزَامٍ، يَقْرَأُ سُورَةَ الْفُرْقَانِ عَلَى غَيْرِ مَا أَقْرَؤُهَا وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَقْرَأَنِيهَا فَكِدْتُ أَنْ أَعْجَلَ عَلَيْهِ ثُمَّ أَمْهَلْتُهُ حَتَّى انْصَرَفَ ثُمَّ لَبَّبْتُهُ بِرِدَائِهِ فَجِئْتُ بِهِ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي سَمِعْتُ هَذَا يَقْرَأُ سُورَةَ الْفُرْقَانِ عَلَى غَيْرِ مَا أَقْرَأْتَنِيهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرْسِلْهُ - ثُمَّ قَالَ - اقْرَأْ يَا هِشَامُ ‏"‏ ‏.‏ فَقَرَأَ الْقِرَاءَةَ الَّتِي سَمِعْتُهُ يَقْرَأُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَكَذَا أُنْزِلَتْ ‏"‏ ‏.‏ ثُمَّ قَالَ لِي ‏"‏ اقْرَأْ ‏"‏ ‏.‏ فَقَرَأْتُهَا فَقَالَ ‏"‏ هَكَذَا أُنْزِلَتْ إِنَّ هَذَا الْقُرْآنَ أُنْزِلَ عَلَى سَبْعَةِ أَحْرُفٍ فَاقْرَءُوا مَا تَيَسَّرَ مِنْهُ ‏"‏ ‏.‏\hadithno{474}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Urwa ibn az- Zubayr that Abd ar-Rahman ibn Abd al-Qari said that he had heard Umar ibn al-Khattab say, "I heard Hisham ibn Hakim ibn Hizam reciting Surat al-Furqan (Sura 25) differently from me, and it was the Messenger of Allah, may Allah bless him and grant him peace, who had recited it to me. I was about to rush up to him but I granted him a respite until he had finished his prayer. Then I grabbed him by his cloak and took him to the Messenger of Allah, may Allah bless him and grant him peace, and said, 'Messenger of Allah, I heard this man reciting Surat al- Furqan differently from the way you recited it to me.' The Messenger of Allah, may Allah bless him and grant him peace, said, 'Let him go.' Then he said, 'Recite, Hisham,' and Hisham recited as I had heard him recite. The Messenger of Allah, may Allah bless him and grant him peace, said, 'It was sent down like that.' Then he said to me, 'Recite' and I recited the sura, and he said, 'It was sent down like that. This Qur'an was sent down in seven (different) ways, so recite from it whatever is easy for you}}
\hadithdefcmd{malik}{475}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا مَثَلُ صَاحِبِ الْقُرْآنِ كَمَثَلِ صَاحِبِ الإِبِلِ الْمُعَقَّلَةِ إِنْ عَاهَدَ عَلَيْهَا أَمْسَكَهَا وَإِنْ أَطْلَقَهَا ذَهَبَتْ ‏"‏ ‏.‏\hadithno{475}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "A man who knows the Qur'an well is like a man who has a hobbled camel. If he takes care of it, he keeps it, and if he lets it go, it gets away}}
\hadithdefcmd{malik}{476}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ الْحَارِثَ بْنَ هِشَامٍ سَأَلَ رَسُولَ اللَّهِ كَيْفَ يَأْتِيكَ الْوَحْىُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَحْيَانًا يَأْتِينِي فِي مِثْلِ صَلْصَلَةِ الْجَرَسِ وَهُوَ أَشَدُّهُ عَلَىَّ فَيَفْصِمُ عَنِّي وَقَدْ وَعَيْتُ مَا قَالَ وَأَحْيَانًا يَتَمَثَّلُ لِيَ الْمَلَكُ رَجُلاً فَيُكَلِّمُنِي فَأَعِي مَا يَقُولُ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ وَلَقَدْ رَأَيْتُهُ يَنْزِلُ عَلَيْهِ فِي الْيَوْمِ الشَّدِيدِ الْبَرْدِ فَيُفْصِمُ عَنْهُ وَإِنَّ جَبِينَهُ لَيَتَفَصَّدُ عَرَقًا ‏.‏\hadithno{476}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father from A'isha, the wife of the Prophet, may Allah bless him and grant him peace, that al-Harith ibn Hisham asked the Messenger of Allah, may Allah bless him and grant him peace, "How does the revelation come to you?" and the Messenger of Allah, may Allah bless him and grant him peace, said, "Sometimes it comes to me like the ringing of a bell, and that is the hardest for me, and when it leaves me I remember what it has said. And sometimes the angel appears to me in the likeness of a man and talks to me and I remember what he says." A'isha added, "I saw it coming down on him on an intensely cold day, and when it had left him his forehead was dripping with sweat}}
\hadithdefcmd{malik}{477}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ أُنْزِلَتْ ‏\{‏عَبَسَ وَتَوَلَّى‏\}‏ فِي عَبْدِ اللَّهِ بْنِ أُمِّ مَكْتُومٍ جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَعَلَ يَقُولُ يَا مُحَمَّدُ اسْتَدْنِينِي وَعِنْدَ النَّبِيِّ صلى الله عليه وسلم رَجُلٌ مِنْ عُظَمَاءِ الْمُشْرِكِينَ فَجَعَلَ النَّبِيُّ صلى الله عليه وسلم يُعْرِضُ عَنْهُ وَيُقْبِلُ عَلَى الآخَرِ وَيَقُولُ ‏"‏ يَا أَبَا فُلاَنٍ هَلْ تَرَى بِمَا أَقُولُ بَأْسًا ‏"‏ ‏.‏ فَيَقُولُ لاَ وَالدِّمَاءِ مَا أَرَى بِمَا تَقُولُ بَأْسًا ‏.‏ فَأُنْزِلَتْ ‏\{‏عَبَسَ وَتَوَلَّى أَنْ جَاءَهُ الأَعْمَى‏\}‏\hadithno{477}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father said that Abasa (Sura 80) was sent down about Abdullah ibn Umm Maktum. He came to the Prophet, may Allah bless him and grant him peace, and began to say, "O Muhammad, show me a place near you (where I can sit)," whilst one of the leading men of the idol worshippers was in audience with the Prophet, may Allah bless him and grant him peace. The Prophet, may Allah bless him and grant him peace, began to turn away from him and give his attention to the other man, and he said to him, "Father of so-and-so, do you see any harm in what I am saying?" and he said, "No, by the blood (of our sacrifices) I see no harm in what you are saying." And Abasa - "He frowned and turned away when the blind man came" - was sent down}}
\hadithdefcmd{malik}{478}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَسِيرُ فِي بَعْضِ أَسْفَارِهِ وَعُمَرُ بْنُ الْخَطَّابِ يَسِيرُ مَعَهُ لَيْلاً فَسَأَلَهُ عُمَرُ عَنْ شَىْءٍ فَلَمْ يُجِبْهُ ثُمَّ سَأَلَهُ فَلَمْ يُجِبْهُ ثُمَّ سَأَلَهُ فَلَمْ يُجِبْهُ ‏.‏ فَقَالَ عُمَرُ ثَكِلَتْكَ أُمُّكَ عُمَرُ نَزَرْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم ثَلاَثَ مَرَّاتٍ كُلُّ ذَلِكَ لاَ يُجِيبُكَ - قَالَ عُمَرُ - فَحَرَّكْتُ بَعِيرِي حَتَّى إِذَا كُنْتُ أَمَامَ النَّاسِ وَخَشِيتُ أَنْ يُنْزَلَ فِيَّ قُرْآنٌ فَمَا نَشِبْتُ أَنْ سَمِعْتُ صَارِخًا يَصْرُخُ بِي - قَالَ - فَقُلْتُ لَقَدْ خَشِيتُ أَنْ يَكُونَ نَزَلَ فِيَّ قُرْآنٌ - قَالَ - فَجِئْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَسَلَّمْتُ عَلَيْهِ فَقَالَ ‏"‏ لَقَدْ أُنْزِلَتْ عَلَىَّ هَذِهِ اللَّيْلَةَ سُورَةٌ لَهِيَ أَحَبُّ إِلَىَّ مِمَّا طَلَعَتْ عَلَيْهِ الشَّمْسُ ‏"‏ ‏.‏ ثُمَّ قَرَأَ ‏\{‏ إِنَّا فَتَحْنَا لَكَ فَتْحًا مُبِينًا ‏\}‏\hadithno{478}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from his father that the Messenger of Allah, may Allah bless him and grant him peace, was on one of his journeys, and one night Umar ibn al-Khattab, who was travelling with him, asked him about something, but he did not answer him. He asked him again, but he did not answer him. Then he asked him again, and again he did not answer him. Umar said, "May your mother be bereaved of you, Umar. Three times you have importuned the Messenger of Allah, may Allah bless him and grant him peace, with a question and he has not answered you at all." Umar continued, "I got my camel moving until, when I was in front of the people, I feared that a piece of Qur'an was being sent down about me. It was not long before I heard a crier calling for me, and I said that I feared that a piece of Qur'an had been sent down about me." He continued, "I came to the Messenger of Allah, may Allah bless him and grant him peace, and said, 'Peace be upon you' to him, and he said, 'A sura has been sent down to me this night that is more beloved to me than anything on which the sun rises.' Then he recited al-Fath (Sura)}}
\hadithdefcmd{malik}{479}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ التَّيْمِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي سَعِيدٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَخْرُجُ فِيكُمْ قَوْمٌ تَحْقِرُونَ صَلاَتَكُمْ مَعَ صَلاَتِهِمْ وَصِيَامَكُمْ مَعَ صِيَامِهِمْ وَأَعْمَالَكُمْ مَعَ أَعْمَالِهِمْ يَقْرَءُونَ الْقُرْآنَ وَلاَ يُجَاوِزُ حَنَاجِرَهُمْ يَمْرُقُونَ مِنَ الدِّينِ مُرُوقَ السَّهْمِ مِنَ الرَّمِيَّةِ تَنْظُرُ فِي النَّصْلِ فَلاَ تَرَى شَيْئًا وَتَنْظُرُ فِي الْقِدْحِ فَلاَ تَرَى شَيْئًا وَتَنْظُرُ فِي الرِّيشِ فَلاَ تَرَى شَيْئًا وَتَتَمَارَى فِي الْفُوقِ ‏"‏ ‏.‏\hadithno{479}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Muhammad ibn Ibrahim ibn al-Harith at-Taymi from Abu Salama ibn Abd ar Rahman that Abu Said said that he had heard the Messenger of Allah, may Allah bless him and grant him peace, say, "A group of people will appear among you whose prayer, fasting and deeds will make you think little of your own prayer, fasting and deeds. They will recite the Qur'an, but it wil not get past their throats, and they will pass through the deen like an arrow passes through game. You look at the arrowhead, and you see nothing, and you look at the shaft, and you see nothing, and you look at the flights, and you see nothing. And you are in doubt about the notch}}
\hadithdefcmd{malik}{480}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، مَكَثَ عَلَى سُورَةِ الْبَقَرَةِ ثَمَانِيَ سِنِينَ يَتَعَلَّمُهَا ‏.‏\hadithno{480}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that it took Abdullah ibn Umar eight years to learn Surat al-Baqara. (Sura)}}
\hadithdefcmd{malik}{481}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، مَوْلَى الأَسْوَدِ بْنِ سُفْيَانَ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، قَرَأَ لَهُمْ ‏\{‏إِذَا السَّمَاءُ انْشَقَّتْ‏\}‏ فَسَجَدَ فِيهَا فَلَمَّا انْصَرَفَ أَخْبَرَهُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَجَدَ فِيهَا ‏.‏\hadithno{481}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Yazid, the mawla of al Aswad ibn Sufyan, from Abu Salama ibn Abd ar Rahman that Abu Hurayra recited al-Inshiqaq (Sura 84) to them and prostrated in it. When he had finished he told them that the Messenger of Allah, may Allah bless him and grant him peace, had prostrated in it}}
\hadithdefcmd{malik}{482}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، مَوْلَى ابْنِ عُمَرَ أَنَّ رَجُلاً، مِنْ أَهْلِ مِصْرَ أَخْبَرَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ قَرَأَ سُورَةَ الْحَجِّ فَسَجَدَ فِيهَا سَجْدَتَيْنِ ثُمَّ قَالَ إِنَّ هَذِهِ السُّورَةَ فُضِّلَتْ بِسَجْدَتَيْنِ ‏.‏\hadithno{482}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Nafi, the mawla of Ibn Umar that a man from Egypt told him that Umar ibn al-Khattab recited Surat al-Hajj (Sura 22) and prostrated twice in it, and then said, "This sura has been given special preference by having two prostrations in it}}
\hadithdefcmd{malik}{483}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّهُ قَالَ رَأَيْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ يَسْجُدُ فِي سُورَةِ الْحَجِّ سَجْدَتَيْنِ ‏.‏\hadithno{483}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Abdullah ibn Dinar said, "I saw Abdullah ibn Umar prostrate twice in Surat al-Hajj (Sura)}}
\hadithdefcmd{malik}{484}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنِ الأَعْرَجِ، ‏.‏ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَرَأَ بِالنَّجْمِ إِذَا هَوَى فَسَجَدَ فِيهَا ثُمَّ قَامَ فَقَرَأَ بِسُورَةٍ أُخْرَى ‏.‏\hadithno{484}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from al-Araj that Umar ibn al Khattab recited Surat an-Najm (Sura 53) and prostrated in it, and then got up and recited another sura}}
\hadithdefcmd{malik}{485}{\hadithno{485}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{}}
\hadithdefcmd{malik}{486}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي صَعْصَعَةَ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّهُ سَمِعَ رَجُلاً، يَقْرَأُ ‏\{‏قُلْ هُوَ اللَّهُ أَحَدٌ‏\}‏ يُرَدِّدُهَا فَلَمَّا أَصْبَحَ غَدَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ وَكَأَنَّ الرَّجُلَ يَتَقَالُّهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ إِنَّهَا لَتَعْدِلُ ثُلُثَ الْقُرْآنِ ‏"‏ ‏.‏\hadithno{486}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{}}
\hadithdefcmd{malik}{487}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عُبَيْدِ بْنِ حُنَيْنٍ، مَوْلَى آلِ زَيْدِ بْنِ الْخَطَّابِ أَنَّهُ قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ أَقْبَلْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَمِعَ رَجُلاً يَقْرَأُ ‏\{‏قُلْ هُوَ اللَّهُ أَحَدٌ‏\}‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَجَبَتْ ‏"‏ ‏.‏ فَسَأَلْتُهُ مَاذَا يَا رَسُولَ اللَّهِ فَقَالَ ‏"‏ الْجَنَّةُ ‏"‏ ‏.‏ فَقَالَ أَبُو هُرَيْرَةَ فَأَرَدْتُ أَنْ أَذْهَبَ إِلَيْهِ فَأُبَشِّرَهُ ثُمَّ فَرِقْتُ أَنْ يَفُوتَنِي الْغَدَاءُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَآثَرْتُ الْغَدَاءَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ ذَهَبْتُ إِلَى الرَّجُلِ فَوَجَدْتُهُ قَدْ ذَهَبَ ‏.‏\hadithno{487}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ubaydullah ibn Abd ar-Rahman that Ubayd ibn Hunayn, the mawla of the family of Zayd ibn al Khattab, said that he had heard Abu Hurayra say, "I was going along with the Messenger of Allah, may Allah bless him and grant him peace, when he heard a man reciting Surat al-Ikhlas (Sura 112). The Messenger of Allah, may Allah bless him and grant him peace, said, 'It is obligatory,' and I asked him, 'What is, Messenger of Allah?' and he said, 'The Garden.' I wanted to tell the man the good news but I was afraid that I would miss the midday meal with the Messenger of Allah, may Allah bless him and grant him peace, and I preferred to eat with the Messenger of Allah, may Allah bless him and grant him peace. When I went to the man afterwards I found that he had gone}}
\hadithdefcmd{malik}{488}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّهُ أَخْبَرَهُ أَنَّ ‏\{‏قُلْ هُوَ اللَّهُ أَحَدٌ‏\}‏ تَعْدِلُ ثُلُثَ الْقُرْآنِ وَأَنَّ ‏\{‏تَبَارَكَ الَّذِي بِيَدِهِ الْمُلْكُ‏\}‏ تُجَادِلُ عَنْ صَاحِبِهَا ‏.‏\hadithno{488}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Humayd ibn Abd ar-Rahman ibn Awf had told him that Surat al-Ikhlas (Sura 112) was equal to a third of the Qur'an, and that Surat al-Mulk (Sura 67) pleaded for its owner}}
\hadithdefcmd{malik}{489}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ فِي يَوْمٍ مِائَةَ مَرَّةٍ كَانَتْ لَهُ عَدْلَ عَشْرِ رِقَابٍ وَكُتِبَتْ لَهُ مِائَةُ حَسَنَةٍ وَمُحِيَتْ عَنْهُ مِائَةُ سَيِّئَةٍ وَكَانَتْ لَهُ حِرْزًا مِنَ الشَّيْطَانِ يَوْمَهُ ذَلِكَ حَتَّى يُمْسِيَ وَلَمْ يَأْتِ أَحَدٌ بِأَفْضَلَ مِمَّا جَاءَ بِهِ إِلاَّ أَحَدٌ عَمِلَ أَكْثَرَ مِنْ ذَلِكَ ‏"‏ ‏.‏\hadithno{489}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Sumayy, the mawla of Abu Bakr, from Abu Salih as-Samman from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Whoever says 'There is no god but Allah, alone, without any partner. The Kingdom and praise belong to Him and He has power over everything' (La ilaha illa'llah, wahdahu la sharika lah, lahu'l mulku wa lahu'l hamd, wa huwa ala kulli shay'in qadir) one hundred times a day, it is the same for him as freeing ten slaves. One hundred good actions are written for him and one hundred wrong actions are erased from him, and it is a protection from Shaytan for that day until the night. No-one does anything more excellent than what he does except someone who does more than that}}
\hadithdefcmd{malik}{490}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ سُبْحَانَ اللَّهِ وَبِحَمْدِهِ فِي يَوْمٍ مِائَةَ مَرَّةٍ حُطَّتْ عَنْهُ خَطَايَاهُ وَإِنْ كَانَتْ مِثْلَ زَبَدِ الْبَحْرِ ‏"‏ ‏.‏\hadithno{490}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Sumayy, the mawla of Abu Bakr, from Abu Salih as-Samman from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Whoever says, 'Glory be to Allah and with His praise' (Subhana'llah wa bi-hamdihi) one hundred times in a day will have his wrong actions taken away from him, even if they are as abundant as the foam on the sea}}
\hadithdefcmd{malik}{491}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي عُبَيْدٍ، مَوْلَى سُلَيْمَانَ بْنِ عَبْدِ الْمَلِكِ عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ مَنْ سَبَّحَ دُبُرَ كُلِّ صَلاَةٍ ثَلاَثًا وَثَلاَثِينَ وَكَبَّرَ ثَلاَثًا وَثَلاَثِينَ وَحَمِدَ ثَلاَثًا وَثَلاَثِينَ وَخَتَمَ الْمِائَةَ بِلاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ غُفِرَتْ ذُنُوبُهُ وَلَوْ كَانَتْ مِثْلَ زَبَدِ الْبَحْرِ ‏"‏ ‏.‏\hadithno{491}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abu Ubayd, the mawla of Sulayman ibn Abd al-Malik, from Ata ibn Yazid al-Laythi that Abu Hurayra said, "Whoever says 'Glory be to Allah' (Subhana'llah) thirty- three times and 'Allah is Greater' (Allahu akbar) thirty-three times and 'Praise be to Allah' (al-hamdu lillah) thirty-three times, and seals the hundred with 'There is no god but Allah, alone without any partner. The Kingdom and praise belong to Him and He has power over everything' (La ilaha illa'llah, wahdahu la sharika lah, lahu'l mulku wa lahu'l hamd, wa huwa ala kulli shay'in qadir) after every prayer will have his wrong actions forgiven him even if they are abundant as the foam on the sea}}
\hadithdefcmd{malik}{492}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عُمَارَةَ بْنِ صَيَّادٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ سَمِعَهُ يَقُولُ فِي الْبَاقِيَاتِ الصَّالِحَاتِ إِنَّهَا قَوْلُ الْعَبْدِ اللَّهُ أَكْبَرُ وَسُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ وَلاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏.‏\hadithno{492}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Umara ibn Sayyad had heard Said ibn al Musayyab say about abiding good deeds that they were a slave's saying 'Allah is greater' (Allahu akbar) and 'Glory be to Allah' (Subahana'llah) and 'Praise be to Allah' (al-hamdu lillah) and 'There is no god but Allah and there is no power and no strength except by Allah.' (La ilaha illa'llah wa la hawla wa la quwwata illa bi'llah)}}
\hadithdefcmd{malik}{493}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زِيَادِ بْنِ أَبِي زِيَادٍ، أَنَّهُ قَالَ قَالَ أَبُو الدَّرْدَاءِ أَلاَ أُخْبِرُكُمْ بِخَيْرِ، أَعْمَالِكُمْ وَأَرْفَعِهَا فِي دَرَجَاتِكُمْ وَأَزْكَاهَا عِنْدَ مَلِيكِكُمْ وَخَيْرٍ لَكُمْ مِنْ إِعْطَاءِ الذَّهَبِ وَالْوَرِقِ وَخَيْرٍ لَكُمْ مِنْ أَنْ تَلْقَوْا عَدُوَّكُمْ فَتَضْرِبُوا أَعْنَاقَهُمْ وَيَضْرِبُوا أَعْنَاقَكُمْ قَالُوا بَلَى ‏.‏ قَالَ ذِكْرُ اللَّهِ تَعَالَى ‏.‏ قَالَ زِيَادُ بْنُ أَبِي زِيَادٍ وَقَالَ أَبُو عَبْدِ الرَّحْمَنِ مُعَاذُ بْنُ جَبَلٍ مَا عَمِلَ ابْنُ آدَمَ مِنْ عَمَلٍ أَنْجَى لَهُ مِنْ عَذَابِ اللَّهِ مِنْ ذِكْرِ اللَّهِ ‏.‏\hadithno{493}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that Ziyad ibn Abi Ziyad said that Abu'd-Darda had said, "Shall I not tell you the best of your deeds, and those that give you the highest rank, and those that are the purest with your King, and are better for you than giving gold and silver, and better for you than meeting your enemy and striking their necks?" They said, "Of course." He said, "Remembrance (dhikr) of Allah ta ala}}
\hadithdefcmd{malik}{494}{وَحَدَّثَنِي مَالِكٌ، عَنْ نُعَيْمِ بْنِ عَبْدِ اللَّهِ الْمُجْمِرِ، عَنْ عَلِيِّ بْنِ يَحْيَى الزُّرَقِيِّ، عَنْ أَبِيهِ، عَنْ رِفَاعَةَ بْنِ رَافِعٍ، أَنَّهُ قَالَ كُنَّا يَوْمًا نُصَلِّي وَرَاءَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا رَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَأْسَهُ مِنَ الرَّكْعَةِ وَقَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ قَالَ رَجُلٌ وَرَاءَهُ رَبَّنَا وَلَكَ الْحَمْدُ حَمْدًا كَثِيرًا طَيِّبًا مُبَارَكًا فِيهِ ‏.‏ فَلَمَّا انْصَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنِ الْمُتَكَلِّمُ آنِفًا ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ أَنَا يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَقَدْ رَأَيْتُ بِضْعَةً وَثَلاَثِينَ مَلَكًا يَبْتَدِرُونَهَا أَيُّهُمْ يَكْتُبُهُنَّ أَوَّلاً ‏"‏ ‏.‏\hadithno{494}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Nuaym ibn Abdullah ibn al-Mujmir from AIi ibn Yahya az-Zuraqi from his father that Rifaa ibn Rafi said, "One day we were praying behind the Messenger of Allah, may Allah bless him and grant him peace, when the Messenger of Allah, may Allah bless him and grant him peace, raised his head from ruku and said, 'Allah hears the one who praises Him' (Sami Allahu liman hamidah). A man behind him said, 'Our Lord, praise belongs to you - blessed, pure and abundant praise' (Rabbana wa laka'l hamd, hamdan kathiran tayiban mubarakan fihi). When the Messenger of Allah, may Allah bless him and grant him peace, had finished, he said, 'Who was it who spoke just now?' The man said, 'I did, Messenger of Allah,' and the Messenger of Allah, may Allah bless him and grant him peace, said, 'I saw more than thirty angels rushing to it to see which one of them would record it first}}
\hadithdefcmd{malik}{495}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لِكُلِّ نَبِيٍّ دَعْوَةٌ يَدْعُو بِهَا فَأُرِيدُ أَنْ أَخْتَبِئَ دَعْوَتِي شَفَاعَةً لأُمَّتِي فِي الآخِرَةِ ‏"‏ ‏.‏\hadithno{495}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Every prophet is given a supplication (dua), and I wish to preserve my dua as intercession for my community in the next world}}
\hadithdefcmd{malik}{496}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَدْعُو فَيَقُولُ ‏ "‏ اللَّهُمَّ فَالِقَ الإِصْبَاحِ وَجَاعِلَ اللَّيْلِ سَكَنًا وَالشَّمْسِ وَالْقَمَرِ حُسْبَانًا اقْضِ عَنِّي الدَّيْنَ وَأَغْنِنِي مِنَ الْفَقْرِ وَأَمْتِعْنِي بِسَمْعِي وَبَصَرِي وَقُوَّتِي فِي سَبِيلِكَ ‏"‏ ‏.‏\hadithno{496}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that he had heard that the Messenger of Allah, may Allah bless him and grant him peace, used to say the following dua, "O Allah, it is You who makes the dawn break and makes the night a time for rest and appoints the sun and moon to reckon by. Relieve me of debt and enrich me from poverty and let me enjoy my hearing, my sight and my strength in Your way." Allahumma faliqa'l isbah, wa ja ila'l-layli sakana, wa 'sh-shamsi wa'l-qamari husbana. Iqda anniy addayna, wa'ghnaniy mina'l faqr. Na'mti aniy bi samiy wa basariy, wa quwwatiy fi sabilik}}
\hadithdefcmd{malik}{497}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَقُلْ أَحَدُكُمْ إِذَا دَعَا اللَّهُمَّ اغْفِرْ لِي إِنْ شِئْتَ اللَّهُمَّ ارْحَمْنِي إِنْ شِئْتَ لِيَعْزِمِ الْمَسْأَلَةَ فَإِنَّهُ لاَ مُكْرِهَ لَهُ ‏"‏ ‏.‏\hadithno{497}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, ''When you are making dua do not say; 'O Allah, forgive me if You wish. O Allah, forgive me if you wish.' You should be firm in your asking, for there is no compelling Him}}
\hadithdefcmd{malik}{498}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي عُبَيْدٍ، مَوْلَى ابْنِ أَزْهَرَ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يُسْتَجَابُ لأَحَدِكُمْ مَا لَمْ يَعْجَلْ فَيَقُولُ قَدْ دَعَوْتُ فَلَمْ يُسْتَجَبْ لِي ‏"‏ ‏.‏\hadithno{498}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Abu Ubayd, the mawla of Ibn Azhar, from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "You will be answered as long as you are not impatient and say, 'I have made a dua and I have not been answered}}
\hadithdefcmd{malik}{499}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي عَبْدِ اللَّهِ الأَغَرِّ، وَعَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَنْزِلُ رَبُّنَا تَبَارَكَ وَتَعَالَى كُلَّ لَيْلَةٍ إِلَى السَّمَاءِ الدُّنْيَا حِينَ يَبْقَى ثُلُثُ اللَّيْلِ الآخِرُ فَيَقُولُ مَنْ يَدْعُونِي فَأَسْتَجِيبَ لَهُ مَنْ يَسْأَلُنِي فَأُعْطِيَهُ مَنْ يَسْتَغْفِرُنِي فَأَغْفِرَ لَهُ ‏"‏ ‏.‏\hadithno{499}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Abu Abdullah al-Agharr and from Abu Salama from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Our Lord, the Blessed and Exalted, descends every night to the heaven of this world when the last third of the night is still to come and says, 'Who will call on Me so that I may answer him? Who will ask Me so that I may give him? Who will ask forgiveness of Me so that I may forgive him?}}
\hadithdefcmd{malik}{500}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ التَّيْمِيِّ، أَنَّ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ، قَالَتْ كُنْتُ نَائِمَةً إِلَى جَنْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَفَقَدْتُهُ مِنَ اللَّيْلِ فَلَمَسْتُهُ بِيَدِي فَوَضَعْتُ يَدِي عَلَى قَدَمَيْهِ وَهُوَ سَاجِدٌ يَقُولُ ‏ "‏ أَعُوذُ بِرِضَاكَ مِنْ سَخَطِكَ وَبِمُعَافَاتِكَ مِنْ عُقُوبَتِكَ وَبِكَ مِنْكَ لاَ أُحْصِي ثَنَاءً عَلَيْكَ أَنْتَ كَمَا أَثْنَيْتَ عَلَى نَفْسِكَ ‏"‏ ‏.‏\hadithno{500}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Muhammad ibn Ibrahim ibn al-Harith at-Taymi that A'isha, umm al-muminin said, "I was sleeping by the side of the Messenger of Allah, mayAllah bless him and grant him peace, and I missed him in the night, so I felt for him with my hand and I put my hand on his feet and he was in sajda saying, 'I seek refuge in Your pleasure from Your wrath, and in Your pardon from Your punishment, and in You from You. I cannot enumerate Your praises as You praise Yourself.' " Audhu bi ridaka min sakhatika, wa bi muafatika min uqubatika wa bika minka, la uhsiy thana'an alayka, anta kama athnayta ala nafsika}}
\hadithdefcmd{malik}{501}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زِيَادِ بْنِ أَبِي زِيَادٍ، عَنْ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ بْنِ كَرِيزٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَفْضَلُ الدُّعَاءِ دُعَاءُ يَوْمِ عَرَفَةَ وَأَفْضَلُ مَا قُلْتُ أَنَا وَالنَّبِيُّونَ مِنْ قَبْلِي لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ ‏"‏ ‏.‏\hadithno{501}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Ziyad ibn Abi Ziyad from Talha ibn Ubaydullah ibn Kariz that the Messenger of Allah, may Allah bless him and grant him peace, said, "The best dua is dua on the day of Arafa, and the best thing that I or the Prophets before me have said is 'There is no god but Allah, alone, without any partner' (La ilaha illa'llah, wahdahu la sharika lah)}}
\hadithdefcmd{malik}{502}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، عَنْ طَاوُسٍ الْيَمَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُعَلِّمُهُمْ هَذَا الدُّعَاءَ كَمَا يُعَلِّمُهُمُ السُّورَةَ مِنَ الْقُرْآنِ يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عَذَابِ جَهَنَّمَ وَأَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏ ‏.‏\hadithno{502}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'zZubayr al-Makki from Tawus al-Yamani from Abdullah ibn Abbas that the Messenger of Allah, may Allah bless him and grant him peace, used to teach this dua in the same way that he would teach them a sura of the Qur'an, "O Allah, I seek refuge in You from the torment of Jahannam, and I seek refuge in You from the trial of the Dajjal, and I seek refuge in You from the trial of life and death." Allahumma inniy audhu bika min adhabi jahannama, wa audhu bika min adhabi'l-qabri, wa audhu bika min fitnati'l-mahya wa mamati}}
\hadithdefcmd{malik}{503}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، عَنْ طَاوُسٍ الْيَمَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا قَامَ إِلَى الصَّلاَةِ مِنْ جَوْفِ اللَّيْلِ يَقُولُ ‏ "‏ اللَّهُمَّ لَكَ الْحَمْدُ أَنْتَ نُورُ السَّمَوَاتِ وَالأَرْضِ وَلَكَ الْحَمْدُ أَنْتَ قَيَّامُ السَّمَوَاتِ وَالأَرْضِ وَلَكَ الْحَمْدُ أَنْتَ رَبُّ السَّمَوَاتِ وَالأَرْضِ وَمَنْ فِيهِنَّ أَنْتَ الْحَقُّ وَقَوْلُكَ الْحَقُّ وَوَعْدُكَ الْحَقُّ وَلِقَاؤُكَ حَقٌّ وَالْجَنَّةُ حَقٌّ وَالنَّارُ حَقٌّ وَالسَّاعَةُ حَقٌّ اللَّهُمَّ لَكَ أَسْلَمْتُ وَبِكَ آمَنْتُ وَعَلَيْكَ تَوَكَّلْتُ وَإِلَيْكَ أَنَبْتُ وَبِكَ خَاصَمْتُ وَإِلَيْكَ حَاكَمْتُ فَاغْفِرْ لِي مَا قَدَّمْتُ وَأَخَّرْتُ وَأَسْرَرْتُ وَأَعْلَنْتُ أَنْتَ إِلَهِي لاَ إِلَهَ إِلاَّ أَنْتَ ‏"‏ ‏.‏\hadithno{503}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z Zubayr al-Makki from Tawus al-Yamani from Abdullah ibn Abbas that the Messenger of Allah, may Allah bless him and grant him peace, used to say, when he rose for prayer in the middle of the night, "O Allah, praise belongs to You. You are the light of the heavens and the earth and praise belongs toYou.You are the Sustainer of the heavens and the earth and praise belongs to You. You are the Lord of the heavens and the earth and whoever is in them. You are the Truth, and Your words are true. Your promise is true, and the meeting with You is true. The Garden is true and the Fire is true and the Hour is true. O Allah, I submit toYou and I accept You and I trust in You and I turn to You and I argue by You and I summon toYou for judgement. Forgive me what I have sent before me and what I have left behind, what I have kept secret and what I have proclaimed, You are my god - there is no god but You." Allahumma laka'l-hamdu anta nuru's-samawati wa'l-ardi, wa laka'l-hamdu anta qayamu's-Samawati wa'l-ardi, wa laka'l-hamdu anta rabbu's-Samawati wa'l-ardi,wamanfihina.Anta'l-haqqu,waqawluka'lhaqqu, wa waduka'l-haqqu, wa liqa'uka haqqun, wa jannatu haqqun, wa naru haqqun, wa sactu haqqun. Allahumma laka aslamtu, wa bikaamantu, waalayka tawakaltu, wa ilayka anabtu, wa bika khasamtu, wa ilayka hakamtu, fa'ghfirliy ma qadamtu wa akhartu wa asrartu, wa alantu. Anta ilahiy, la ilaha illa ant}}
\hadithdefcmd{malik}{504}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ جَابِرِ بْنِ عَتِيكٍ، أَنَّهُ قَالَ جَاءَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ فِي بَنِي مُعَاوِيَةَ - وَهِيَ قَرْيَةٌ مِنْ قُرَى الأَنْصَارِ - فَقَالَ هَلْ تَدْرُونَ أَيْنَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ مَسْجِدِكُمْ هَذَا فَقُلْتُ لَهُ نَعَمْ وَأَشَرْتُ لَهُ إِلَى نَاحِيَةٍ مِنْهُ فَقَالَ هَلْ تَدْرِي مَا الثَّلاَثُ الَّتِي دَعَا بِهِنَّ فِيهِ فَقُلْتُ نَعَمْ ‏.‏ قَالَ فَأَخْبِرْنِي بِهِنَّ ‏.‏ فَقُلْتُ دَعَا بِأَنْ لاَ يُظْهِرَ عَلَيْهِمْ عَدُوًّا مِنْ غَيْرِهِمْ وَلاَ يُهْلِكَهُمْ بِالسِّنِينَ فَأُعْطِيَهُمَا وَدَعَا بِأَنْ لاَ يَجْعَلَ بَأْسَهُمْ بَيْنَهُمْ فَمُنِعَهَا ‏.‏ قَالَ صَدَقْتَ ‏.‏ قَالَ ابْنُ عُمَرَ فَلَنْ يَزَالَ الْهَرْجُ إِلَى يَوْمِ الْقِيَامَةِ ‏.‏\hadithno{504}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that Abdullah ibn Abdullah ibn Jabir ibn Atik said that Abdullah ibn Umar had come to them in Bani Muawiya, one of the villages of the Ansar, and said, "Do you know where the Messenger of Allah, may Allah bless him and grant him peace, prayed in this mosque of yours? "I told him, "Yes," and I pointed out a place near where he was. He said, "Do you know the three things for which he made dua here?" I said "Yes." He said, "Tell me them then." I said, "He asked that He would not make an enemy from among the non- believers triumph over the believers and that He would not destroy the believers by bad harvests, and he was given both these things. And he asked that He would not make the believers fight among themselves, and that was refused." Ibn Umar said, "You have told the truth," and he added, "Turmoil will not cease until the day of rising}}
\hadithdefcmd{malik}{505}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّهُ كَانَ يَقُولُ مَا مِنْ دَاعٍ يَدْعُو إِلاَّ كَانَ بَيْنَ إِحْدَى ثَلاَثٍ إِمَّا أَنْ يُسْتَجَابَ لَهُ وَإِمَّا أَنْ يُدَّخَرَ لَهُ وَإِمَّا أَنْ يُكَفَّرَ عَنْهُ ‏.‏\hadithno{505}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Zayd ibn Aslam used to say, "No-one makes a dua without one of three things happening. Either it is answered, or it is stored up for him, or wrong actions are atoned for by it}}
\hadithdefcmd{malik}{506}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، قَالَ رَآنِي عَبْدُ اللَّهِ بْنُ عُمَرَ وَأَنَا أَدْعُو، وَأُشِيرُ، بِأَصْبُعَيْنِ أَصْبُعٍ مِنْ كُلِّ يَدٍ فَنَهَانِي ‏.‏\hadithno{506}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Abdullah ibn Dinar said, "Abdullah ibn Umar saw me when I was making dua and I was pointing with two fingers, one from each hand, and he forbade me}}
\hadithdefcmd{malik}{507}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، كَانَ يَقُولُ إِنَّ الرَّجُلَ لَيُرْفَعُ بِدُعَاءِ وَلَدِهِ مِنْ بَعْدِهِ وَقَالَ بِيَدَيْهِ نَحْوَ السَّمَاءِ فَرَفَعَهُمَا ‏.‏\hadithno{507}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Said ibn al-Musayyab used to say, "A man is raised by the dua of his son after his death." He spoke with his hands turned upwards, and then lifted them up}}
\hadithdefcmd{malik}{508}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ إِنَّمَا أُنْزِلَتْ هَذِهِ الآيَةُ ‏\{‏وَلاَ تَجْهَرْ بِصَلاَتِكَ وَلاَ تُخَافِتْ بِهَا وَابْتَغِ بَيْنَ ذَلِكَ سَبِيلاً‏\}‏ فِي الدُّعَاءِ ‏.‏ قَالَ يَحْيَى وَسُئِلَ مَالِكٌ عَنِ الدُّعَاءِ فِي الصَّلاَةِ الْمَكْتُوبَةِ فَقَالَ لاَ بَأْسَ بِالدُّعَاءِ فِيهَا ‏.‏\hadithno{508}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father said, "The following ayat was sent down about dua - 'And do not be loud in your prayer and do not be silent in it, but seek a way between these.' " (Sura 17 ayat 110) Yahya said that Malik was asked about making dua in obligatory prayers and he said, "There is no harm in making dua in them}}
\hadithdefcmd{malik}{509}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَدْعُو فَيَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَسْأَلُكَ فِعْلَ الْخَيْرَاتِ وَتَرْكَ الْمُنْكَرَاتِ وَحُبَّ الْمَسَاكِينِ وَإِذَا أَرَدْتَ فِي النَّاسِ فِتْنَةً فَاقْبِضْنِي إِلَيْكَ غَيْرَ مَفْتُونٍ ‏"‏ ‏.‏\hadithno{509}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik that he had heard that the Messenger of Allah, may Allah bless him and grant him peace, used to make dua saying, "O Allah, I askYou for good actions and for leaving what is disapproved of and for love of the poor. And if You wish to try people, then bring me to You without being tried." Allahumma inniy asa'luka fala'l-khayrati, wa tarqa'l-munqarati, wa hubba'l-masakin, wa idha aradta fi'n-nasi fitnatan fa'qbithni ilayka ghayra maftun}}
\hadithdefcmd{malik}{510}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ دَاعٍ يَدْعُو إِلَى هُدًى إِلاَّ كَانَ لَهُ مِثْلُ أَجْرِ مَنِ اتَّبَعَهُ لاَ يَنْقُصُ ذَلِكَ مِنْ أُجُورِهِمْ شَيْئًا وَمَا مِنْ دَاعٍ يَدْعُو إِلَى ضَلاَلَةٍ إِلاَّ كَانَ عَلَيْهِ مِثْلُ أَوْزَارِهِمْ لاَ يَنْقُصُ ذَلِكَ مِنْ أَوْزَارِهِمْ شَيْئًا ‏"‏ ‏.‏\hadithno{510}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik that he had heard that the Messenger of Allah, may Allah bless him and grant him peace, said, "No one calls to guidance without having the same reward as those who follow him without diminishing their rewards at all. And no one calls to error without having the same burdens as they do without diminishing their burdens at all}}
\hadithdefcmd{malik}{511}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ اللَّهُمَّ اجْعَلْنِي مِنْ أَئِمَّةِ الْمُتَّقِينَ ‏.‏\hadithno{511}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Abdullah ibn Umar said, "O Allah, make me one of the leaders of the people of taqwa ." Allahumma jalniy min a'imati'l-mutaqin}}
\hadithdefcmd{malik}{512}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ أَبَا الدَّرْدَاءِ، كَانَ يَقُومُ مِنْ جَوْفِ اللَّيْلِ فَيَقُولُ نَامَتِ الْعُيُونُ وَغَارَتِ النُّجُومُ وَأَنْتَ الْحَىُّ الْقَيُّومُ ‏.‏\hadithno{512}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Abu'd-Darda used to rise in the middle of the night and say, "Eyes have slept, and stars have set, and You are the Living and Self Subsistent." Namat'l uyun wa ghariti'n-nujum wa anta'lhayyu-l-qayyum}}
\hadithdefcmd{malik}{513}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ الصُّنَابِحِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الشَّمْسَ تَطْلُعُ وَمَعَهَا قَرْنُ الشَّيْطَانِ فَإِذَا ارْتَفَعَتْ فَارَقَهَا ثُمَّ إِذَا اسْتَوَتْ قَارَنَهَا فَإِذَا زَالَتْ فَارَقَهَا فَإِذَا دَنَتْ لِلْغُرُوبِ قَارَنَهَا فَإِذَا غَرَبَتْ فَارَقَهَا ‏"‏ ‏.‏ وَنَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الصَّلاَةِ فِي تِلْكَ السَّاعَاتِ ‏.‏\hadithno{513}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Ata ibn Yasar from Abdullah as-Sunabihi that the Messenger of Allah, may Allah bless him and grant him peace, said, "The sun rises and with it is a horn of Shaytan and when the sun gets higher the horn leaves it. Then when the sun reaches the meridian the horn joins it and when the sun declines the horn leaves it, and when the sun has nearly set it joins it again." The Messenger of Allah, may Allah bless him and grant him peace, forbade prayer at these times}}
\hadithdefcmd{malik}{514}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا بَدَا حَاجِبُ الشَّمْسِ فَأَخِّرُوا الصَّلاَةَ حَتَّى تَبْرُزَ وَإِذَا غَابَ حَاجِبُ الشَّمْسِ فَأَخِّرُوا الصَّلاَةَ حَتَّى تَغِيبَ ‏"‏ ‏.‏\hadithno{514}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father said that the Messenger of Allah, may Allah bless him and grant him peace, used to say, "Delay the prayer when the edge of the sun appears until it is completely in view, and delay the prayer when the edge of the sun is disappearing until it has completely disappeared}}
\hadithdefcmd{malik}{515}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ دَخَلْنَا عَلَى أَنَسِ بْنِ مَالِكٍ بَعْدَ الظُّهْرِ فَقَامَ يُصَلِّي الْعَصْرَ فَلَمَّا فَرَغَ مِنْ صَلاَتِهِ ذَكَرْنَا تَعْجِيلَ الصَّلاَةِ أَوْ ذَكَرَهَا فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ تِلْكَ صَلاَةُ الْمُنَافِقِينَ تِلْكَ صَلاَةُ الْمُنَافِقِينَ تِلْكَ صَلاَةُ الْمُنَافِقِينَ يَجْلِسُ أَحَدُهُمْ حَتَّى إِذَا اصْفَرَّتِ الشَّمْسُ وَكَانَتْ بَيْنَ قَرْنَىِ الشَّيْطَانِ - أَوْ عَلَى قَرْنِ الشَّيْطَانِ - قَامَ فَنَقَرَ أَرْبَعًا لاَ يَذْكُرُ اللَّهَ فِيهَا إِلاَّ قَلِيلاً ‏"‏ ‏.‏\hadithno{515}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that al-Ala ibn Abd ar-Rahman said, "We visited Anas ibn Malik after dhuhr and he stood up and prayed asr. When he had finished his prayer, we mentioned doing prayers early in their time, or he mentioned it, and he said that he had heard the Messenger of Allah, may Allah bless him and grant him peace, say, the prayer of the hypocrites, the prayer of the hypocrites, the prayer of the hypocrites is that one of them sits until the sun becomes yellow and is between the horns of Shaytan, or on the horn of Shaytan, and then gets up and rattles off four rakas, hardly remembering Allah in them at all}}
\hadithdefcmd{malik}{516}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَتَحَرَّ أَحَدُكُمْ فَيُصَلِّيَ عِنْدَ طُلُوعِ الشَّمْسِ وَلاَ عِنْدَ غُرُوبِهَا ‏"‏ ‏.‏\hadithno{516}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "You should not intend to pray either at sunrise or sunset}}
\hadithdefcmd{malik}{517}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الصَّلاَةِ بَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ وَعَنِ الصَّلاَةِ بَعْدَ الصُّبْحِ حَتَّى تَطْلُعَ الشَّمْسُ ‏.‏\hadithno{517}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Muhammad ibn Yahya ibn Habban from al Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, forbade prayer after asr until the sun had set, and prayer after subh until the sun had risen}}
\hadithdefcmd{malik}{518}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، كَانَ يَقُولُ لاَ تَحَرَّوْا بِصَلاَتِكُمْ طُلُوعَ الشَّمْسِ وَلاَ غُرُوبَهَا فَإِنَّ الشَّيْطَانَ يَطْلُعُ قَرْنَاهُ مَعَ طُلُوعِ الشَّمْسِ وَيَغْرُبَانِ مَعَ غُرُوبِهَا وَكَانَ يَضْرِبُ النَّاسَ عَلَى تِلْكَ الصَّلاَةِ ‏.‏\hadithno{518}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Dinar from Abdullah ibn Umar that Umar ibn al-Khattab used to say, "Do not intend to do your prayer at either sunrise or sunset, for the horns of Shaytan rise with the rising of the sun and set with its setting." Umar used to beat people for that kind of prayer}}
\hadithdefcmd{malik}{519}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنِ السَّائِبِ بْنِ يَزِيدَ، أَنَّهُ رَأَى عُمَرَ بْنَ الْخَطَّابِ يَضْرِبُ الْمُنْكَدِرَ فِي الصَّلاَةِ بَعْدَ الْعَصْرِ ‏.‏\hadithno{519}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from as-Sa'ib ibn Yazid that he saw Umar ibn al-Khattab beating al-Munkadir for praying after asr}}
